package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````I18``#0```"8@0````0`!30`(``)
M`"@`&P`:``$``'#H>P``Z'L``.A[```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````#T>P``]'L```4`````$```
M`0```+Q]``"\C0``O(T``(P"``"@`@``!@`````0```"````Q'T``,2-``#$
MC0``"`$```@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DO'T`
M`+R-``"\C0``1`(``$0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`$^`R<U;,#+/7_6H&4S55%E.,'2D$
M````$`````$```!'3E4```````,````"`````````!$```!+````"`````@`
M```!D!`$)4`$@"B```6@AE"$@($``@LH!(PX@!)!B@``"$L```!,````3P``
M`%,```!4````70```%X```!?`````````&$```!B````8P```&0```!E````
M:````````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[;49-1\=E0\E"'_Y`[9
M<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=YNN.2?/JA;&"93\.;:PE#UF>O
MS&9"1=7LB0=PTS-BV^T5C"7,#3J7"W^IG)O@IP(*:AJ>4+_:5QNCX/M)````
M``````````````````````#8$0````````,`"P```````)`````````#`!8`
M"0(`````````````$@```.0``````````````!(```#Z`@`````````````2
M````Q0(`````````````$@```+<"`````````````!(```"6````````````
M```2````70$`````````````$@```/H``````````````!(````!````````
M```````@````L`(`````````````$@```"4"`````````````!(````K`0``
M```````````2````&P$`````````````$@```+X"`````````````!(````-
M`0`````````````2````U`$`````````````$@```!```````````````"``
M``![`0`````````````2````S0(`````````````$@```.D`````````````
M`!(```#W`0`````````````2````U`(`````````````$@```"P`````````
M`````"````#\`0`````````````2````1@``````````````$@```&,`````
M`````````!8```!-`0`````````````2````=@``````````````$@```-,`
M`````````````!(```"'```````````````2````Z@$`````````````$@``
M`-P!`````````````!(```#;`@`````````````2````Y`,`````````````
M$@```+<``````````````!(````*`P`````````````1````S0$`````````
M````$@```"0#`````````````!$````/`@`````````````2````/P$`````
M````````$@```,0!`````````````!(```"#`@`````````````2````O0$`
M````````````$@```.X``````````````!(```"K`0`````````````2````
M=`$`````````````$@```)4!`````````````!(```!C`@`````````````2
M````XP$`````````````$@```/$!`````````````!(````2`P``````````
M```2````H@``````````````$@```!X"`````````````!(```!H`0``````
M```````2````-@(`````````````$@````@#`````````````!$```"3`@``
M```````````1````Q@``````````````$0```+,!`````````````!(```"&
M`0`````````````1````1P(`````````````$@`````#`````````````!(`
M```T`0`````````````2````50(`````````````$@```#\"````````````
M`!(```!4```````````````2````<0(`````````````$@```)H"````````
M`````!(```#B`@`````````````2````I@$`````````````$@```.D"````
M`````````!(```"A`@`````````````B````/P0``%R0````````$``7`.T#
M``#E+```P````!(`#0!D!```&28``/@$```2``T`?@(``-D4``#,`0``$@`-
M`&0#```E'0``!````!(`#0""`P``$2L``-0!```2``T`%00``$B0````````
M$``7`(H$```I'0``H`$``!(`#0!*!```2)`````````0`!<`=0,``,D>```8
M````$@`-`)@#``")(P``8````!(`#0#Y`P``\#D```0````1``\`(P0``$$X
M``#8````$@`-`"X$```]'```/````!(`#0`V!```7)`````````0`!<`7P0`
M`%R0````````$``7`'@$``!=)0``O````!(`#0"A!```Z2,``$@````2``T`
M"`0```"0````````$``6`+P#``#A'@``#`$``!(`#0!Q!```2)`````````0
M`!8`EP0``$20```$````$0`6``X$``"E%@```````!(`#0!6!```S3<``'0`
M```2``T`"@0```"0````````(``6`-(#``!-)0``$````!(`#0"F`P``>1P`
M`*P````2``T`R`,``!DY``"^````$@`-`#X$``!<D````````!``%P"I!```
M[1\``)P#```2``T``%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-
M0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES
M7W1E<FT`4&5R;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?
M871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C
M<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E
M<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F
M;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L
M7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R
M`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?
M;65M;W)Y7W=R87``7U]S=&%C:U]C:&M?9F%I;`!E>&ET`&QS965K-C0`<F5A
M9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`<W1R<F-H<@!U;FQI;FL`
M<W1R=&]K`'-T<FQE;@!R;61I<@!R96%D`%]?;65M8W!Y7V-H:P!M:V1I<@!?
M7W9F<')I;G1F7V-H:P!G971P:60`7U]L<W1A=#8T7W1I;64V-`!R96%D;&EN
M:P!R96%L;&]C`%]?<W!R:6YT9E]C:&L`7U]M96UM;W9E7V-H:P!?7V9P<FEN
M=&9?8VAK`%]?;&EB8U]S=&%R=%]M86EN`%]?<W1A=#8T7W1I;64V-`!S=&1E
M<G(`;65M8VAR`%]?8WAA7V9I;F%L:7IE`'-T<F-H<@!M96UC;7``;65M<V5T
M`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC<'D`<W1R8VUP`%]?97)R;F]?
M;&]C871I;VX`86)O<G0`<W1R;F-M<`!?7V5N=FER;VX`7U]R96=I<W1E<E]A
M=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU+C,X`&QI8F,N
M<V\N-@!L9"UL:6YU>"UA<FUH9BYS;RXS`'!A<E]C=7)R96YT7V5X96,`<&%R
M7V)A<V5N86UE`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!S:&%?9FEN86P`
M9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/7W-T
M9&EN7W5S960`7U]D871A7W-T87)T`%]?8G-S7W-T87)T7U\`<VAA7W5P9&%T
M90!X<U]I;FET`%]?96YD7U\`7U]B<W-?96YD7U\`7U]B<W-?<W1A<G0`<VAA
M7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L:6)P
M871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?:6YI=%]E
M;G8`1TQ)0D-?,BXT`$=,24)#7S(N,S0```````````(``0`"``(``@`!``$`
M`0`!``(``P`!``$``@`!``(``0`!``(``@`"``(``0`"``$``0`!``$``0`!
M``(``@`"``(``0`"``(`!``"``$``@`#``(``0`"``(``@`"``(``@`"``$`
M`@`!``(``@`"``$``@`!``(``@`!``(``@`!``,``@`"``(``@`"``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!`````0`!`%`#```0````(````!1I:0T```0`M@0````````!
M``(`1@,``!``````````M)&6!@```P#`!```$````!1I:0T```(`M@0`````
M``"\C0``%P```,"-```7````_(\``!<````$D```%P```!20```7````&)``
M`!<````@D```%P```"20```7````*)```!<````LD```%P```#"0```7````
M.)```!<````\D```%P```$20```7````R(\``!4*``#,CP``%0L``-"/```5
M$P``U(\``!49``#8CP``$QP``-R/```5'0``X(\``!4>``#DCP``%28``.B/
M```5*```[(\``!4[``#PCP``%3P``/2/```5/@``^(\``!5*``#8C@``%@,`
M`-R.```6!```X(X``!8%``#DC@``%@8``.B.```6!P``[(X``!8(``#PC@``
M%@D``/2.```6"P``^(X``!8,``#\C@``%@T```"/```6#@``!(\``!8/```(
MCP``%A````R/```6$0``$(\``!82```4CP``%A0``!B/```6%0``'(\``!86
M```@CP``%A<``"2/```6&```*(\``!8:```LCP``%AL``#"/```6'P``-(\`
M`!8@```XCP``%B$``#R/```6(@``0(\``!8C``!$CP``%B0``$B/```6)0``
M3(\``!8G``!0CP``%BD``%2/```6*@``6(\``!8K``!<CP``%BP``&"/```6
M+0``9(\``!8N``!HCP``%B\``&R/```6,```<(\``!8Q``!TCP``%C(``'B/
M```6,P``?(\``!8T``"`CP``%C4``(2/```6-@``B(\``!8W``",CP``%C@`
M`)"/```6.0``E(\``!8]``"8CP``%C\``)R/```60```H(\``!9!``"DCP``
M%D(``*B/```60P``K(\``!9$``"PCP``%D4``+2/```61@``N(\``!9'``"\
MCP``%D@``,"/```620``Q(\``!9*```(0"WI/0$`ZPB`O>@$X"WE!."?Y0[@
MC^`(\+[EV'P```#&C^('RHSBV/R\Y0#&C^('RHSBT/R\Y0#&C^('RHSBR/R\
MY0#&C^('RHSBP/R\Y0#&C^('RHSBN/R\Y0#&C^('RHSBL/R\Y0#&C^('RHSB
MJ/R\Y0#&C^('RHSBH/R\Y0#&C^('RHSBF/R\Y0#&C^('RHSBD/R\Y0#&C^('
MRHSBB/R\Y0#&C^('RHSB@/R\Y0#&C^('RHSB>/R\Y0#&C^('RHSB</R\Y0#&
MC^('RHSB:/R\Y0#&C^('RHSB8/R\Y0#&C^('RHSB6/R\Y7A'_><`QH_B!\J,
MXDS\O.4`QH_B!\J,XD3\O.4`QH_B!\J,XCS\O.4`QH_B!\J,XC3\O.4`QH_B
M!\J,XBS\O.4`QH_B!\J,XB3\O.4`QH_B!\J,XAS\O.4`QH_B!\J,XA3\O.4`
MQH_B!\J,X@S\O.4`QH_B!\J,X@3\O.4`QH_B!\J,XOS[O.4`QH_B!\J,XO3[
MO.4`QH_B!\J,XNS[O.4`QH_B!\J,XN3[O.4`QH_B!\J,XMS[O.4`QH_B!\J,
MXM3[O.4`QH_B!\J,XLS[O.5X1_WG`,:/X@?*C.+`^[SE`,:/X@?*C.*X^[SE
M`,:/X@?*C.*P^[SE`,:/X@?*C.*H^[SE`,:/X@?*C.*@^[SE`,:/X@?*C.*8
M^[SE`,:/X@?*C.*0^[SE`,:/X@?*C.*(^[SE>$?]YP#&C^('RHSB?/N\Y0#&
MC^('RHSB=/N\Y0#&C^('RHSB;/N\Y0#&C^('RHSB9/N\Y0#&C^('RHSB7/N\
MY0#&C^('RHSB5/N\Y0#&C^('RHSB3/N\Y0#&C^('RHSB1/N\Y7A'_><`QH_B
M!\J,XCC[O.4`QH_B!\J,XC#[O.4`QH_B!\J,XBC[O.4`QH_B!\J,XB#[O.4`
MQH_B!\J,XAC[O.4`QH_B!\J,XA#[O.4`QH_B!\J,X@C[O.4`QH_B!\J,X@#[
MO.4`QH_B!\J,XOCZO.4`QH_B!\J,XO#ZO.5PM5Y-BK!>2WU$7DS-Z080!JD%
MD@>H!:I\1.M8&V@)DT_P``/_]\+O5TI82Z)8`Y(11N-8!),81@+P8OI42^-8
M'7@`+6/0'>YP+TI+!YA[1!MHQ1P$,+#Q@$_26)+XUC-#\`,#@OC6,W32@`#_
M]VSO2$E)2@-&>40&G'I$"6A08"!HF6!%20>:>4398$1)`2H88'E$66!EW2$=
M!.N"#@/Q#`Q1^`1+3/@$3XY%^='1'#Q,`"``D"I&?$1#^"$`.DG@:'E$__=0
M[@`H,=`W30BN?43H:/_WX.X$1C5(,49X1`#P\OA`LS-+>T38:/_W'N[_]Y;N
M,$HB2WI$TU@::`F;6D!/\``#,M$@1@JP<+W_]V+N*DIZ1-!@,+/_]X[N%DL=
M[G`O>T0;:--8@_B^5HSGX&C_]S+NR>>H:!"Q`?!F^]'G'T@Q1GA$`/"^^*A@
M`"C)T//G&TL<2'A$XU@#DQE&__?F[@0AH^<!(/_W..__]\#N`+^N>@``V'D`
M`.AY```<`0``V'D``/P````4`0``)`$``/)Z``#V>@``1"@``#8H``"X>@``
M,P8``*!Z``".)0``B'H``/AX``!<>@``PB0``"@!``"P)@``3_``"T_P``X"
MO&I&!+0!M-_X&*`%HYI$3_```PBT!$A:^```__?B[O_WH.W\=P``,`$``!0P
MG^44()_E`S"/X`(@D^<``%+C'O\O`=7^_^KD=P````$```9(!TL'2GA$>T1Z
M1(-"`]`%2]-8`[$81W!'`+]">0``0'D``,)W```$`0``"$@)2WA$"4I[1!L:
M>D39#P'KHP%)$`/0!4O36`.Q&$=P1P"_&'D``!1Y``"4=P``"`$```BU"DL*
M2GM$>D0;>&NY"4O36".Q"$M[1!AH__>J[O_WO_\&2P$B>T0:<`B]XG@``&1W
M```L`0``CG@``,)X``#$YP"_+>GX0X!&'TM[1``H-M`>2IM8T_@`D+GQ``\Q
MT`5X#T8`+1B_/2T4OP$E`"43T=GX`$!LL4Y&*D9!1B!&__<X[A"Y8UT]*Q#0
M5O@$3P`L\M$@1KWH^(,%1A7X`3\`*QB_/2OYT:7K"`7AYZ;K"08!-2Q$MA`^
M8"!&O>CX@P1&Y^=,1N7G('<``!@!```72AA+>D00M01&GK#36&E&&V@=DT_P
M``/_]P[MH+D$FP/T<$.S]2!/&+^S]8!/#=`-2@Q+>D336!IH'9M:0$_P``,+
MT1ZP$+T`(/'G`B$@1O_W,.VP^H#P0`GIY__WGNV8=@``'`$``&AV```V2C=+
M>D3PM:&PTU@;:!^33_```Q"Q`W@$1ENY,4HP2WI$TU@::!^;6D!/\``#4]$A
ML/"]__>F[`5&`"CNT"A&__>N[0`H-M##?`#Q$P8N*P+1<W@`*_+0PWPN*S+0
M($;_]Q#M!T8P1O_W#.T'1`(W.$;_]UCM'$LZ1@(A>T0!E@"4!D;_]Y+M`JDP
M1O_W,.T!,#!&!=`&FP/T<$.S]8!/%]#_]_;L,$;_]\+L*$;_]WCM`"C(T2A&
M__<4[2!&__=*[:OG<W@N*\G1LW@`*[;0Q>?_]Y7_YN?_]RKM+'8``!P!```0
M=@``;"$``%I*6TMZ1"WI\$\,1H.P!4;36-_X8($;:`&33_```PMX^$0]*PB_
M`30@1O_WMNQI1@9&*$;_]_+^@48`*%30__>L[(9"1]E,2P"?6/@#@+\`*W@`
M*QB_/2L4OP$C`",'T"M&$_@!+P`J&+\]*OG16QNP'-CX`&`81/_WWNSP4>BQ
MV/@`,"A&V5D0^`$["W`]*QB_`"L)T$H<$/@!.Q%&`O@!.P`K&+\]*_;1"D8]
M(PMP%/@!.P+X`3\`*_G1+THL2WI$TU@::`&;6D!/\``#2M$#L+WH\(\)\?\Y
M%/@!.PGX`3\`*_G1Z><C2UCX`X#8^`!P.VB;LSM&4_@$+TE&"?$!"0`J^-$#
M,4_J@0L<2WM$&FC"N5A&`2(:8/_WCNR"1@`HR]`Y1D_JB0=;1CI&__?<[,CX
M`*#-^`"0"?$!"0`C2O@I,(3G648X1O_WU.R"1LCX````*+'03^J)!^OGF49/
M\`@+TN?_]V[L`+]`=0``'`$``"1U```8`0``A'0``+9U```MZ?!!#T8L22Q+
MK?6`77E$@K`&1@WU@%`$,`WQ!`C+6$#V_W)!1AMH`V!/\``#)$AX1/_W>.P$
M'@?=`JUC'@7K`PP<^`0LZKG;N1E+'>YP#SI&,49[1!MHP%C_]YCK&4H-]8!1
M%4L$,7I$TU@::`MH6D!/\``#&-$-]8!=`K"]Z/"!'$8B1B\A0$;_]X3L`"C;
MT`A('>YP7R-&0D9X1`!H,48H6/_WSNO9Y__W"NP`OWAT```P=```LG,``!P!
M``!0'P``6',``#"U'>YP3Q)*#TF%L!%(>D1Y1`EH$$L`)7M$$EA@6`])`Y)Y
M1/_W-.P(20U+>40):`Q*>T1Z1&!8"TD!E7E$`)/_]WCK!;`PO?1S``#8<P``
MZG(``!`!``!87P``IAX``)HA```)#P``J!X```I*@K`*21WN<,]Z1`9("4MX
M1`!H4EA[1`=)7/@``'E$`9("L/_W_+N(<P``@G(``!`!``#N7@``/AX``"5*
M\+4E2WI$K?4`78>P#?4`40.LTU@4,0WU@%8;:`M@3_```__WNNL=2@(A'4L0
M-GI$S>D``GM$($9!\@$"__?&ZR!&3_2`4C%&__>TZP0>N+\`)0S;9QPX1O_W
M=.L%1C"Q.T8Q1B)&__<$ZP`C*U4-2@WU`%$)2Q0Q>D336!IH"VA:0$_P``,$
MT2A&#?4`70>P\+W_]USK2G(``!P!```P'@``'AX``-9Q``#_]ZB_6THMZ?!/
M!D9:2WI$K?6$78.P64@-]815#?$0"--8#$9X1$%&!#4;:"M@3_```__W(_TO
M(05&,$;_]WKJP+%/2#%&>$3_]PK^,$9-2@WUA%%(2P0Q>D336!IH"VA:0$_P
M``-`\(.`#?6$70.PO>CPCR!&__?^ZD-)>43_]Q[K!$8`*-S0(W@-\8@*W_C\
MD*KQ!`?Y1``K2-`EL2%&*$;_]W#KN+,@1O_WINI#'B-$@T:<0CZ_(Q@`(6`<
M`],*X)A"&7`#T!/X`2TO*OC0($;_]Y+J@T8P1O_WCNI81`$PL/6`7ZS2*4@"
M(4M&3_2`4GA$`)3-Z0$&.$;_]Q#K048X1O_WKNHPN5KX:#P#]'!#L_4`3Q?0
M'DD`('E$__?.Z@1&`"B,T"-X`"NVT=6Q*W@N*P30&$Q/\`$+?$3+YVMX`"OH
MT/;G`2$X1O_W-NH`*.'1$4@Y1GA$__>!_3A&__>(ZG/G#DQ/\`$+?$2SY__W
MF.J6<0``'`$``)@=``""'0``3'$``%P=``!&'0``\AP``+P<``!\'```<!P`
M`$P<```0M2\A!$;_]^CI`+%$'"!&O>@00/_W6KH[2O"U.TMZ1*WU@%V#L`WU
M@%'36`0Q&V@+8$_P``,`*#S0`W@%1@`K.-#_]PCJ0AP$1K+U@%]'V`&O*48X
M1O_W"NIC'CM$GT(+TC@9#?$%`@`A`N"00@%P`]`0^`$]+ROXT"\A.$;_]ZSI
M>+.X0H2_`",#<#A&__<@ZA]*#?6`41Q+!#%Z1--8&F@+:%I`3_```RO1#?6`
M70.P\+T72@WU@%$42P0Q>D336!IH"VA:0$_P``,:T1)(>$0-]8!=`["]Z/!`
M__?VN0`@UN<-2@WU@%$(2P0Q>D336!IH"VA:0$_P``,"T0A(>$3FY__W_.GB
M;P``'`$``&1O``!";P``1!L``!)O```4&P``S$K-2WI$<+7,3H*PS$W36'Y$
M;$9]1!MH`9-/\``#(48P1O_WQ_NPL<9+`)CK6!EH`>N``UIH0?@@(``J[]`$
M,UIH0_@$*P`J^M$A1C!&__>Q^P`HZ-&\3GY$(48P1O_WJ?NPL;=+`)CK6!EH
M`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>3^P`HZ-&N3GY$(48P
M1O_WB_NPL:A+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&
M__=U^P`HZ-&@3GY$(48P1O_W;?NPL9E+`)CK6!EH`>N``UIH0?@@(``J[]`$
M,UIH0_@$*P`J^M$A1C!&__=7^P`HZ-&23GY$(48P1O_W3_NPL8I+`)CK6!EH
M`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__<Y^P`HZ-&$3GY$(48P
M1O_W,?NPL7M+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&
M__<;^P`HZ-%V3GY$(48P1O_W$_NPL6Q+`)CK6!EH`>N``UIH0?@@(``J[]`$
M,UIH0_@$*P`J^M$A1C!&__?]^@`HZ-%H3GY$(48P1O_W]?JPL5U+`)CK6!EH
M`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__??^@`HZ-%:3GY$(48P
M1O_WU_JPL4Y+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&
M__?!^@`HZ-%,3GY$(48P1O_WN?JPL3]+`)CK6!EH`>N``UIH0?@@(``J[]`$
M,UIH0_@$*P`J^M$A1C!&__>C^@`HZ-$^3GY$(48P1O_WF_JPL3!+`)CK6!EH
M`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>%^@`HZ-$P2"%&>$3_
M]W[Z`488L2U(>$3_]VK[+$@A1GA$__=S^@%&&+$J2'A$__=?^RE((49X1/_W
M:/H!1K"Q)DAX1/_W5/LE2A%+>D336!IH`9M:0$_P``,5T2%)(DAY1'A$`K"]
MZ'!`__=!NQ]((49X1/_W2OH!1@`HY-`<2'A$__<U^]_G__=4Z-AN```<`0``
M$!L``,AN```8`0``U!H``*`:``!P&@``/!H``!`:``!P&0``I!D``'09``!$
M&0``C!@``-88``"R&```U!@``-P8``#>&```"A@``.AK``#8&```/A@``+(8
M```\&```$TH42WI$`+432(.PTUAX1&E&&V@!DT_P``/_]_WY0+$`>``H&+\P
M*`R_`2``((#P`0`*2@=+>D336!IH`9M:0$_P``,"T0.P7?@$^_[W^.\\:P``
M'`$``+H7```*:P``#[3?^#3``+4,2OQ$@[`$JPM)#$A<^`(@>402:`&23_``
M`E/X!"L`DPA8`B$`:/[WIN__(/_W2NC6:@``'`$``,AJ```@`0``+>GP1P(A
M/TRM]8`]`"*&L'Q$#?6`-0`C%#6`1@"1.DEA6`EH*6!/\``!_O>J[P$X8?$`
M!_H7@.H"`YL:F[)30)L:8NL"`L8:9^L"!P`O2]M/\`@)P/(!"0.M`"$R1CM&
M0$8`D?[WC.^Q\?\_"+^P\?\_0=!*1BE&0$;^]Q3O0QPVT`<H)MD(."P8(]+?
M^'R@^D0"X`$\K$(<TP@B448@1O[WJNX`*/719!N@&4?KY'$72@WU@#042Q0T
M>D336!IH(VA:0$_P``,:T0WU@#T&L+WH\(>V]8`V9_$`![?Q_S\(OQ;U@#^X
MT4_P_S`!1M_G"$AX1/_W8/\'2'A$__=<__[W2N^(:@``'`$``$1K``#>:0``
MOA8``*86```(M?[WM.[^]_;N`+$`:`B])DHG2WI$\+4F3X>P!4;36']$!*DX
M1AMH!9-/\``#__<1^1"Q`W@$1HNY'TH<2WI$TU@::`6;6D!/\``#+-$;2"E&
M>$0'L+WH\$#_]^VY*$;^][;N!D8@1O[WLNX&1`(V,$;^]_[N$DL223)&>T0"
ME'E$`)4!D0(A!$;^]S;O#DH'2WI$TU@::`6;6D!/\``#!+\A1CA&U=#^]^CN
M:&D``!P!``"`%@``/FD``$X6```X%0``,!4``.IH```MZ?!/W_AL),&PW_AL
M%'I$W_AH5'E$)J\(DGU$W_A@)`7Q#`,'D`7Q&`PLK#`U)D8-\:0)BE@-\2@(
M$F@_DD_P``*3Z`<`A^@'`+SH#P`/QISH`P"&Z`,`E>@'`(GH!P#?^"`$049X
M1/_WCO@@L0-X!48`*T#P?H'^]Q+N_O=4[@`H`/"O@`9H`"X`\*N`,$;^]SCN
M0@`"\0$*4$;^]X+N!48P>``H`/!W@=-&"97?^-B3^4121DM&`)`"(2A&`C7^
M][3NTT46^`$/6T8XOU-&H^L*`JKQ`@H",JKK`PJ:0BR_DD2:1``HY-'H2'A$
M`N!4^`0/B+%!1O_W1O@%1@`H]M`#>``K\]#_]X3X`"COT"A&_O<V[@1&B+E7
M^`1+=+$C>``K`/`0@2!&__=S^``H\]`@1O[W).X$1@`H[=`@1O[WX.T)G09&
M*$;^]]SM!D0&\@1&,$;^]R;NS4L'1C)&>T0"D\M+`B$#E7M$`9/*2P"4>T3^
M]UKN3_3@<3A&_O<P[0$P!='^]Y#N`6@1*4#PXX!!1CA&_O=:[01&`"@\T+Y)
M")@'F[Y*0%@"(1MH>D0`EP!H_O<"[@`ENDJP2WI$TU@::#^;6D!/\``#0/!,
M@2A&0;"]Z/"/_O?2[09&`"A`\+2`6?@$"UBQ04;^]\S_`"CWT`-X`"ONT5GX
M!`L`*//1J4X-($_P#0O^]\SM?D0%1@F0VD93($GG#IL#]'!#L_6`3[S1$)W^
M]SKMA4*WT0Z;P_,(`[/UX'^QT3!&_O>R[05&F4A!1GA$_O>=_P%&`"@`\*.`
M!YL8:/_W6?J#1@`H`/";@%A&_O=,[8%&`R@0V8])!#A81'E$_O<*[DBYN?$$
M#P#PV8#91!GX!3PO*P#PTX"'2$%&>$3^]W7_(+$#>#`K&+\`*P;16$8`(?[W
M2.V`1@`H==%_28!(>43?^`"B>$3?^/R1__=0^-_X^('^]Y3M?4M^2@(A>T3-
MZ0!S?$MZ1`*0*$8#DGM$,D;Z1/E$^$3^]YKM$^#^]];M`V@1*Q71_O=Z[0$T
MA$931C)&`B$H1LWI`TG-Z0&,`)?^]X;M3_3@<2A&_O=:[`$PY-`X1O[WONQH
M2"E&>$3_]Q;X*$;_]__]..<<1OCF_O?:[$(``O$!"J#F4$H(F`>;@%@;:%Y*
MS>D`<0(A>D0`:/[W)NTAY__WYOU92D%+>D336!IH/YM:0$_P``-MT2A&0;"]
MZ/!/_O?RO`F5IN8'F]/X`+!@Y__W./V!1K'Q``J#V[#Q"@)/\``+:O$``T!&
MS?@`L/[WZNPRJ08B0$8'D?[W=NP'F08H2=$RFD_TAD/$\D$SFD)_]&BOBHA$
M\DA3FD)_]&*ON?$R`D!&:O$``S2LS?@`L/[WR.Q`1B@B(4;^]U;L*"@JT3-+
M,D8S22A&>T3-Z0!S,4MY1`*4`Y%[1`(AC?CXL/[W^NQZYP>;T_@$D+GQ``\_
M]":O2$;^]USL`RA_]B"O)DD$.$A$>43^]QCM`"@(O\M&%>?^]Z+L(4AX1/_W
MKORB:```G&@``-)I```<`0``8A0``#H5``"8%```H!0``(83``""%```(`$`
M`)84``#R9@``UA,``%`4```H%```H!(``/@2``!V$@``[A,``)04``#^$0``
M%A(``*(4``#B$P``CA$``)X2```T90``TA```%X3``"0$@``3A(``$(2``!D
M265*>41PM5I+@K`=[G!/BEAN1F%(,482:`&23_```GM$&VAX1.58E?AH,(7X
M:3#^]R[^$+$#>#$K?-#_]T[Z34M[1!MHY5A522A&`R,!(GE$_O>,ZP5&<+$"
M:4=+>T0;:!%H3TK@6'I$_O>,ZRMI&6B+:%L":]1!20,C`2)Y1`EH8%A(27E$
M_O=PZP5&>+%&2#%&>$3^]_O]`D8`*$[0.$LI:7M$&V@):.!8_O=JZS5+`2(^
M27M$&VAY1.58*$;^]S#K.TH!1BA&>D0Z3?[W6NLN2SE(?41[1!MH`")X1#%&
MXUB#^&D@_O?2_01&J&"PL4_TX'$@1O[W]NI"'`-&$2@8OP$J+-@M2B-+>D33
M6!IH`9M:0$_P``,@T0*P<+UH:/_W\?P$1JA@`"CAT25(>$3^]^+K0W@`*X70
M?N<B2RII>T00:%MH&6C^]U7_K^</2WM$&VC@6/[WG.N,Y_[WK.L:22)&&DAY
M1'A$26@):/[WPNND9```@F0``&9D``!&9```(&0```YD``#L8P``<F,``+1C
M```<`0```!```*@1``"4$0``?A$``$@/``!.$0``5A$``&)D``#R#@``K&(`
M`/@0``#V8P``T&,``.(0```I2BI+>D0PM01&*4B#L--8:49X1!MH`9-/\``#
M_O=._7"Q`W@`*QB_,"L,OP$C`".#\`$#`"P,OP`C`_`!`UNY'$H:2WI$TU@:
M:`&;6D!/\``#)]$#L#"](W@`*_#0($;_]\SX+R$%1O[WJ.H`L44<*$;^]R#K
M$$D$(GE$_O=VZP`HW=$-2@E+>D336!IH`9M:0$_P``,%T2!&`["]Z#!`_O>(
MO?[W'NO@80``'`$``%H.``"@80``N@X``%QA````````+>GP3P-&W_@02JWU
M*WT#\8`'W_@(.GQ$"*D`)@*0"D9`,+Q&XU@;:*F33_```U#I`G168-9@$#(_
MND+X$'PC"B4"`_1_0P@P0^H48P7T?P5#Z@1C8$5#Z@4#0O@(/.;1W>DB@@JL
M)IL-\8@)`),DJ":M`?4"<P.0($8$E<WI!4$-:,WX')"11MWXE.#=^)S`"9_=
M^"RP))[=^"B@`)D!DP'@DD:;1@"1`"/0Z0X44/@(+T-G44"!Z@@!L$9#:&E`
M`)Y51EQ`A.H)!/%&?$#F1D_JT7Q)&$SJ1`P!G$'J#`%?1D_P``R$0@%GVM$#
MFP*8W>D%01UH!)O0Z0%[&V@#D]#I`SI/ZIL.T/@`P`IH(6A.ZH-^A&E']ID3
MQ?:"(P"4!&K2&$_JW&`!E$#J1Q`2&0"<0.I,$-WX')""&(KJ!`!.ZHM^`.H+
M`-WX,(!@0-GX`&`2&$_JG`F*Z@X`R1A)ZH=Y`.H,`$GJC'D)&8#J"@`.GP@8
MCNH)`1CK`P@10`#K\F`8ZPH(@>H.`4_JL@(8ZP$!_Q@7ZPX(`>OP9XGJ`@'=
M^$#@`4!/ZK``@>H)`1CK`0$>ZP,.'NL)"0'K]VZ"Z@`!W?A(@#E`3^JW!U%`
M&>L!`1CK`P@8ZP()@.H'`MWX4(`"Z@X"`>O^84)`3^J^#AGK`@(8ZP,(&.L`
M"0+K\6"'Z@X"W?A8@`I`3^JQ`7I`&>L"`ACK`P@8ZP<)`NOP9X[J`0+=^&"`
M`D!/ZK``@NH.`AGK`@(8ZP,(&.L."0+K]VZ!Z@`"W?AH@#I`3^JW!TI`&>L"
M`ACK`P@8ZP$)`NO^88#J!P+=^'"``NH.`D_JO@Y"0!GK`@(8ZP,(&.L`"0+K
M\6"'Z@X"W?AX@`I`3^JQ`7I`&>L"`ACK`P@8ZP<)`NOP9X[J`0+=^("``D!/
MZK``@NH.`@.<&>L"`ACK`P@8ZPX.`NOW:('J``(Z0$_JMP=*0![K`@+V&'88
M@.H'`0'J"`$"Z_AB04!/ZK@(<1CM&"T8`>OR8(?J"`$10$_JL@*(Z@(&>4!I
M&`9`*)WD&`'K\&&&Z@@&3^JP`.09I!F"Z@`'[1@/0!7K"`8JG03K\6170$_J
ML0'V&8#J`0[M&*\8#NH$#BR=3^JT`H[J``X&Z_1F%^L.!('J`@?M&#=`+1@N
MF$]`!.OV9.\93^JV!L,8,)U;&(+J!@$A0`?K]&Y10$_JM`18&$[VH3/&]MEC
M,ID5ZP,(`.O^8!CK`@B&Z@0"@NH.`D_JO@48ZP((A.H%#LH8-)\(Z_!ACNH`
M#I(93^JP`!+K#@(VGO\8A>H`#@+K\6*.Z@$./!E/ZK$!%.L.!#B?]AB`Z@$.
M!.OR9([J`@YU&4_JL@(5ZPX%.IZ!Z@(._QB.Z@0./Q@%Z_1@%^L.!T_JM`06
MZP,./)T>ZP$.!^OP88+J!`='0$_JL``>ZP<.[Q@^GK\8#NOQ8H3J``Z.Z@$.
M3^JQ`1?K#@<6ZP,.0)T>ZP0.!^OR9(#J`0=70$_JL@(>ZP<.[QA"GC\8#NOT
M8('J`@Z.Z@0.3^JT!!?K#@=$G8+J!`[V&`?K\&>.Z@`.=AA/ZK``%NL.!D:9
MA.H`#NT8!NOW9H[J!PZM&$_JMP<5ZPX%2)K)&(#J!PX%Z_9ECNH&#@P93^JV
M!A3K#@1*F=(8A^H&#@3K]62.Z@4.$!A/ZK4%$.L.`$R:ANH%#LD8`.OT8([J
M!`[)&4_JM`01ZPX!3I^%Z@0.TA@!Z_!ACNH`#I(93^JP`!+K#@)0GO\8A.H`
M#@+K\6*.Z@$.?1E/ZK$!%>L.!5*?]AB`Z@$.CNH"#C09%.L.!`7K\F87ZP,.
M3^JR`E2='NL`#H'J`@`$Z_9D<$`>ZP`.3^JV`.T8@NH`!FD85IUF0`[K]&Z)
M&4_JM`3K&%B=FQB`Z@0"@NH.`D_JO@>:&$OVW$/(]AMS`>O^8>T81.H'#EJ>
M*!@.Z@$.!.H'!4[J!0X"Z_%B$.L.#D_JL0'P&%R=`!E'Z@$$#NOR9A1`!^H!
M#D_JL@)$Z@X$`>H"""08[1A!Z@(`%>L'#C!`!.OV95Z<0.H(`$_JM@80ZPX.
MX!@.Z_5D0!A"Z@8!`NH&#BE`8)]!Z@X!3^JU!0D8`>OT8/\81NH%`0;J!0ZZ
M&"%`8I]/ZK0$0>H.`07J!`B)&/\81>H$`A?K!@X"0&2?`>OP84+J"`)/ZK``
M$NL.`O\8!.H`#GT9`NOQ9T3J``)FG@I`3^JQ`4+J#@+=^*#A51GR&!(90.H!
M!$_JMP8%Z_=E/$``Z@$'/$-!Z@8'HA@>ZP,$)!@!Z@8.:I@O0`+K]6)'Z@X'
M3^JU!3P91NH%!\`8!.OR9`;J!0Y`&!=`3^JR`6R:1^H.!S\81>H!`-(8($"2
M&0?K]&8%Z@$'3^JT!#A#0>H$!X`8;IH!Z@0.-T#2&`#K]F!5&7":1^H.!T_J
MM@9_&=(851@'Z_!A1.H&!P3J!@YRF@=`1^H.!T_JL`!]&=(8$AE&Z@`$!NH`
M!PQ`/$,%Z_%EI!ATFD_JL0$$Z_5DTAA`Z@$'`.H!#I89+T!VFD?J#@=/ZK4%
MOQG2&!88!^OT8$'J!0<!Z@4.>)HG0$?J#@=/ZK0$OQE%Z@0&TA@&0%(8!^OP
M807J!`=/ZK``/D,"G[88`"($Z@`.!NOQ9GI@^F!ZFM(851D`(GIA^F%$Z@`'
M?)H/0$?J#@=/ZK$!?QG2&$#J`04'Z_9G$NL$#C5`3^JV!'Z:`.H!!C5#`>H$
M!A7K#@73&!L80>H$`#A`@)HP0P7K]V7`&$SRUA/,]F(C3^JW!]88@IIV&(3J
M!P%I0`#K]6!V&$_JM072&(?J!0$4&82:04`&Z_!F9!A/ZK``TAB%Z@`!UQF&
MF@3K]F1Q0'\83^JV!M$8B)I)&0?K]&6`Z@8'9T!/ZK0$R1G7&#\8BIJ&Z@0`
M`>OU86A`3^JU!3\8T!B`&8R:!^OQ9H3J!0=/0$_JL0'`&=<8/QF.FH7J`00`
MZ_9@=$`_&4_JM@36&)":=AD'Z_!E@>H$!T=`3^JP`/89UQA_&)*:!NOU883J
M``9N0$_JM06_&=88-AF4F@?K\62`Z@4'3T!/ZK$!]AG7&#\8EIH&Z_1@A>H!
M!F9`3^JT!+\9UAAV&9B:!^OP98'J!`='0$_JL`#V&=<8?QB:F@;K]6&$Z@`&
M;D!/ZK4%OQG6&#89G)H'Z_%D@.H%!T]`3^JQ`?89UQ@_&)Z:!NOT8(7J`09F
M0$_JM`2_&=88=AF@F@?K\&6!Z@0'1T!/ZK``]AG2&%<8!NOU8:*:A.H`!FY`
M3^JU!;\9TA@6&0?K\62`Z@4'I)I/0$_JL0'W&0*>!^OT9](8$!@*Z[<",F&F
MFH7J`09F0$_JM`2`&=,8@>H$`@#K]V!Z0!/K#`,"GUL9FQ@0ZPL"`^OP8P"8
M.V`!FR08NF`,2LD8`"-[8@E+>D2\83EBTU@::*F;6D!/\``#`]$-]2M]O>CP
MC_WW!NX`OPIA```<`0``*E<```BU@"#]]_3MG^T.>P`B@F>`[0![G^T->X#M
M`GN?[0U[@.T$>Y_M#7N`[09[G^T->X#M"'N?[0U[@.T*>X#M#'L(O0"_`2-%
M9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#````````````````
M+>GX0P5&%D:`:@`C#$;W%]7I#"$`Z\8,A$7H:G/K```"T@$R0?$``:AO!?$X
M",7I"L-S#T/JQP.;&"MC0>M7<6EC@+L_+D7=IO%`"4_JF19W'`3KAQ<A1D-&
M!/%`#M'X`,`0,5'X#$P0,U'X"`Q1^`0L<45#^!#,0_@,3$/X"`Q#^`0LZ]$,
M1BA&__=M^KQ"X=&IZX86,D8Y1D!&_?<J[:YGO>CX@\#Q0`<%\3@(MT)`1*B_
M-T8A1CI&_?<<[:MO.T2K9T`K[-$H1O8;/$3_]TOZM^<G1M[G+>GP00'Q.`<,
M1HMJ!48*:Y/Z@_C#\\4#%KI9'(`B."GZ5$7=P?%``G@8`"']]Z#L($;_]RWZ
M.$8X(@`A_?>8["!&Q.D<:/_W(_KC>"MP($9CB&MP(V@;"JMP(VCK<.-Z*W%C
MB6MQHV@;"JMQHVCK<>-\*W)CBFMR(VD;"JMR(VGK<N-^*W-CBVMSHVD;"JMS
MHVGK<Y3X(S`K=&.,:W0C:AL*JW0C:NMTO>CP0?WW?KQX&,'Q.`(`(?WW6NS`
MYP"_`DM[1!MH_?<+O0"_)E8```A`+>D(@+WH`0`"`#X```!!````#````$$`
M```1````00```"<```!!````-@```$$````#````00````8```!!````%0``
M`$$````/````00````X```!!````)@```$$````3````00```"D```!!````
M`@```$$````9````00````H```!!````"P```$$``````````````"5S+R5S
M````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`+@``
M`%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O````
M4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])
M3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<`
M``!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?
M5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"
M04Q?0TQ%04X`````,0```&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9`!,
M1%],24)205)97U!!5$@`4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A
M<BT`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@``4$%42`````!P87)L`````"YP87(`````<VAO<G0@
M<F5A9```)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M
M<"TE=2TE=25S`````!@```!P97)L`````#````!005(Z.E!A8VME<CHZ5D52
M4TE/3@`````Q+C`V,P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T
M;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````+64``"TM``!54T52````
M`%5315).04U%`````%1%35!$25(`5$U0`"]T;7``````979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H
M)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I
M>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%
M7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S
M:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@
M9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ
M92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY
M("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@
M("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ
M90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D
M("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD[
M"FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I
M('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]
M"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F
M:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%4
M12`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI
M.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\
M/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL
M96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64[
M"FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES
M=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.
M('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA
M;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<
M)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO
M=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*
M;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)
M0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO
M<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@
M<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A
M(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G
M:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG
M("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'
M24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I
M8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D
M8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U
M;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U
M9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S
M971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE
M.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E
M="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`[
M"B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I
M<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@
M97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U
M=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_
M.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT
M*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE
M.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0[
M"GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN
M9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN
M9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T
M96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN
M9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M
M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U
M;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II
M<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E
M;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q
M6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E
M860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F
M:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A
M;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968[
M"B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@
M*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE
M<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U
M;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY
M("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA
M<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S
M(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H
M;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD
M?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF
M("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D
M<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT
M('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE
M?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S
M(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM
M>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@
M)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^
M+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M
M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*
M<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E
M9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N
M86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A
M<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII
M9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ
M4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C
M:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@
M,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN
M9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ
M6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL
M96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*
M;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M
M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T
M('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB
M97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U
M=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=
M*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R
M86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!
M4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*
M;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@
M/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(
M12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I
M8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I
M"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H
M95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C
M86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I
M('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@
M,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*
M;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA
M;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I
M('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P
M96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O
M;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF
M(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@
M;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS
M=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.
M04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O
M9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?
M4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB
M*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI
M;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D
M96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.
M5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@
M>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE
M=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%
M04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF
M("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]
M"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2![
M"G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*
M?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L
M(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA
M<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV
M96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*
M<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI0
M05(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O
M<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@
M9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`[
M"GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ
M.PI?7T5.1%]?"@!P97)L>'-I+F,`````0T%#2$4``#X```!!````#````$$`
M```1````00```"<```!!````-@```$$````#````00````8```!!````%0``
M`$$````/````00````X```!!````)@```$$````3````00```"D```!!````
M`@```$$````9````00````H```!!````"P```$$``````````````+R:_W\!
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````)T7``!=%P```0```#8#```!````1@,```$```!0`P``
M#````-@1```-````Z#D``!D```"\C0``&P````0````:````P(T``!P````$
M````]?[_;[0!```%````,`D```8```"@`@``"@```,L$```+````$````!4`
M`````````P```,R.```"````X`$``!0````1````%P```/@/```1````(`\`
M`!(```#8````$P````@````>````"````/O__V\!```(_O__;]`.``#___]O
M`@```/#__V_\#0``^O__;PX`````````````````````````````````````
M````````````````````Q(T`````````````Y!$``.01``#D$0``Y!$``.01
M``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``Y!$`
M`.01``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``
MY!$``.01``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``Y!$``.01``#D
M$0``Y!$``.01``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``Y!$``.01
M``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``````
M````````````````````````````````````````````````````````````
M`````-D4````````!)````I005(N<&T*`````,P]``#@.@```````*`[``"D
M.P``P#T``.@Z``#(/0```````*P]``"T/0```````-0]``!'0T,Z("A58G5N
M='4@,3,N,BXP+3(S=6)U;G1U-"D@,3,N,BXP`$$R````865A8FD``2@````%
M-RU!``8*!T$(`0D""@02!!,!%`$5`1<#&`$9`1H"'`$B`0`N<VAS=')T86(`
M+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU
M+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I
M;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D
M871A`"Y!4DTN97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T
M=')I8G5T97,`````````````````````````````````````````````````
M````````"P````$````"````5`$``%0!```9```````````````!````````
M`!,````'`````@```'`!``!P`0``)```````````````!``````````F````
M!P````(```"4`0``E`$``"````````````````0`````````-````/;__V\"
M````M`$``+0!``#L````!0`````````$````!````#X````+`````@```*`"
M``"@`@``D`8```8````#````!````!````!&`````P````(````P"0``,`D`
M`,L$``````````````$`````````3@```/___V\"````_`T``/P-``#2````
M!0`````````"`````@```%L```#^__]O`@```-`.``#0#@``4`````8````"
M````!`````````!J````"0````(````@#P``(`\``-@````%``````````0`
M```(````<P````D```!"````^`\``/@/``#@`0``!0```!4````$````"```
M`'P````!````!@```-@1``#8$0``#```````````````!`````````!W````
M`0````8```#D$0``Y!$``/0"``````````````0````$````@@````$````&
M````V!0``-@4```0)0`````````````(`````````(@````!````!@```.@Y
M``#H.0``"```````````````!`````````".`````0````(```#P.0``\#D`
M`/A!``````````````0`````````E@````$``'""````Z'L``.A[```(````
M#0`````````$`````````*$````!`````@```/![``#P>P``!```````````
M````!`````````"K````#@````,```"\C0``O'T```0```````````````0`
M```$````MP````\````#````P(T``,!]```$```````````````$````!```
M`,,````&`````P```,2-``#$?0``"`$```8`````````!`````@```#,````
M`0````,```#,C@``S'X``#0!``````````````0````$````T0````$````#
M`````)````"```!(```````````````$`````````-<````(`````P```$B0
M``!(@```%```````````````!`````````#<`````0```#``````````2(``
M`"8```````````````$````!````Y0````,``'```````````&Z````S````
M```````````!``````````$````#``````````````"A@```]0``````````
+`````0``````````
